@@ -1,4 +1,4 @@
-import jpe.Jfloat as jfloat
+from jpe.Jfloat import Jfloat as jfloat
 from jpe.random import perlinNoise
 import jpe.math.linalg
 import jpe.crono.timer as crono
